#  BELOW IS THE CODING USED FOR THE DIFFERENT ANALYSES FOR THE PAPER. THIS CONSISTED OF 
#  GLMM ANALYSES AND MONTHLY FISHING EFFORT PLOTS. PRIOR TO THE FINAL GLMM ANALYSES, PRELIMINARY 
#  TESTS WERE RUN. ONCE THESE WERE COMPLETE THE GLMM MODELS WERE RUN WITH THE INTERCEPT 
#  INCLUDED AND EXCLUDED.

#  A .CSV FILE WAS USED TO EXTRACT THE RELEVANT DATA FOR THE VARIOUS ANALYSES. PLEASE MAKE 
#  SURE TO SPECIFY WHERE YOU ARE WORKING FROM WITH THE "setwd" CODING BELOW. THIS LOCATION 
#  SHOULD ALSO BE WHERE THE .CSV FILES HAVE BEEN SAVED. AN EXAMPLE IS INCLUDED BELOW.


##SET THE WORKING FOLDER LOCATION WHERE THE .CSV FILES ARE SAVED ----

setwd("C:/Users/gjordaan/Dropbox/Journal Papers/Shark bycatch")


1.#####GLMM ANALYSES (GAMMA AND BINOMIAL)## ----
#####DESCRIPTION AND DATASET USED----

# Statistical model of shark occurrence and density, single species

#GLMM- fit of glmm hurdle models 
                          

SharkSetCPUE<- read.table("Raw_Data_Individual_Set_Data_GLMM_5.csv", header=TRUE, sep=",", na.strings="NA", dec=".", strip.white=TRUE)
westSharkCPUE <- read.table("WEST_SUBREGION.csv", header=TRUE, sep=",", na.strings="NA", dec=".", strip.white=TRUE)
swestSharkCPUE <- read.table("SOUTHWEST_SUBREGION.CSV", header=TRUE, sep=",", na.strings="NA", dec=".", strip.white=TRUE)
southSharkCPUE <- read.table("SOUTH_SUBREGION.csv", header=TRUE, sep=",", na.strings="NA", dec=".", strip.white=TRUE)
eastSharkCPUE <- read.table("EAST_SUBREGION.csv", header=TRUE, sep=",", na.strings="NA", dec=".", strip.white=TRUE)

westSharkCPUE$YEAR <- as.factor(westSharkCPUE$YEAR)
westSharkCPUE$MONTH <- as.factor(westSharkCPUE$MONTH)
westSharkCPUE$VESSEL <- as.factor(westSharkCPUE$VESSEL)
westSharkCPUE$REGION <- as.factor(westSharkCPUE$REGION)
westSharkCPUE$FLEET <- as.factor(westSharkCPUE$FLEET)
westSharkCPUE$OBSERVER <- as.factor(westSharkCPUE$OBSERVER)

swestSharkCPUE$YEAR <- as.factor(swestSharkCPUE$YEAR)
swestSharkCPUE$MONTH <- as.factor(swestSharkCPUE$MONTH)
swestSharkCPUE$VESSEL <- as.factor(swestSharkCPUE$VESSEL)
swestSharkCPUE$REGION <- as.factor(swestSharkCPUE$REGION)
swestSharkCPUE$FLEET <- as.factor(swestSharkCPUE$FLEET)
swestSharkCPUE$OBSERVER <- as.factor(swestSharkCPUE$OBSERVER)

southSharkCPUE$YEAR <- as.factor(southSharkCPUE$YEAR)
southSharkCPUE$MONTH <- as.factor(southSharkCPUE$MONTH)
southSharkCPUE$VESSEL <- as.factor(southSharkCPUE$VESSEL)
southSharkCPUE$REGION <- as.factor(southSharkCPUE$REGION)
southSharkCPUE$FLEET <- as.factor(southSharkCPUE$FLEET)
southSharkCPUE$OBSERVER <- as.factor(southSharkCPUE$OBSERVER)

eastSharkCPUE$YEAR <- as.factor(eastSharkCPUE$YEAR)
eastSharkCPUE$MONTH <- as.factor(eastSharkCPUE$MONTH)
eastSharkCPUE$VESSEL <- as.factor(eastSharkCPUE$VESSEL)
eastSharkCPUE$REGION <- as.factor(eastSharkCPUE$REGION)
eastSharkCPUE$FLEET <- as.factor(eastSharkCPUE$FLEET)
eastSharkCPUE$OBSERVER <- as.factor(eastSharkCPUE$OBSERVER)

library("lme4")            # alternative package for glmm  #functions with present data
library("stats")
library("lmtest")             #for ANOVA tests in glm and glmer

##### WEST AREA ---- 
#####SMA-GAMMA WEST ######################################

westSharkCPUE <- droplevels(westSharkCPUE)
WSMACPUE <- subset(westSharkCPUE, SMA>0)

#GAMMA DISTRIBUTION#

#MODEL 1

sharkgV <- glmer(SMA~(1|VESSEL)-1,data=WSMACPUE, family="Gamma"(link=log))
summary(sharkgV)
AIC(sharkgV)
BIC(sharkgV)
coefficients(sharkgV)
exp(fixef(sharkgV))
ranef(sharkgV)

#MODEL 2

sharkgVYear <- glmer(SMA~(1|VESSEL) + YEAR-1, data=WSMACPUE,family="Gamma"(link=log))
summary(sharkgVYear)
AIC(sharkgVYear)
BIC(sharkgVYear)
coefficients(sharkgVYear)
exp(fixef(sharkgVYear))
ranef(sharkgVYear)

#MODEL 3

sharkgVYearM <- glmer(SMA~(1|VESSEL) + YEAR + MONTH -1, data=WSMACPUE,family="Gamma"(link=log))
summary(sharkgVYearM)
AIC(sharkgVYearM)
BIC(sharkgVYearM)
coefficients(sharkgVYearM)
exp(fixef(sharkgVYearM))
ranef(sharkgVYearM)

#MODEL 4

sharkgVYearMF <- glmer(SMA~(1|VESSEL) + YEAR + MONTH + FLEET -1, data=WSMACPUE,family="Gamma"(link=log))
summary(sharkgVYearMF)
AIC(sharkgVYearMF)
BIC(sharkgVYearMF)
coefficients(sharkgVYearMF)
exp(fixef(sharkgVYearMF))
ranef(sharkgVYearMF)

#MODEL 5

sharkgVYearMFO <- glmer(SMA~(1|VESSEL) + YEAR + MONTH + FLEET + OBSERVER-1, data=WSMACPUE,family="Gamma"(link=log))
summary(sharkgVYearMFO)
AIC(sharkgVYearMFO)
BIC(sharkgVYearMFO)
coefficients(sharkgVYearMFO)
exp(fixef(sharkgVYearMFO))
ranef(sharkgVYearMFO)

#####SMA-BINOMIAL WEST ################################

# MODEL BINARY OUTCOMES (catch or zero catch)

WSMACPUEb = westSharkCPUE

#make binary values of catch (0=no catch, 1 =catch)
WSMACPUEb$SMAb=0
WSMACPUEb$SMAb[WSMACPUEb$SMA>0]=1

#MODEL 1

sharkbV <- glmer(SMAb~(1|VESSEL)-1, data=WSMACPUEb,family=binomial)
summary(sharkbV)
AIC(sharkbV)
BIC(sharkbV)
coefficients(sharkbV)
fixef(sharkbV)
ranef(sharkbV)

#MODEL 2

sharkbVYear <- glmer(SMAb~(1|VESSEL) + YEAR -1, data=WSMACPUEb,family=binomial)
summary(sharkbVYear)
AIC(sharkbVYear)
BIC(sharkbVYear)
coefficients(sharkbVYear)
fixef(sharkbVYear)
ranef(sharkbVYear)

#MODEL 3

sharkbVYearM <- glmer(SMAb~(1|VESSEL) + YEAR + MONTH -1,data=WSMACPUEb,family=binomial)
summary(sharkbVYearM)
AIC(sharkbVYearM)
BIC(sharkbVYearM)
coefficients(sharkbVYearM)
fixef(sharkbVYearM)
ranef(sharkbVYearM)

#MODEL 4

sharkbVYearMF <- glmer(SMAb~(1|VESSEL) + YEAR + MONTH + FLEET -1, data=WSMACPUEb,family=binomial)
summary(sharkbVYearMO)
AIC(sharkbVYearMO)
BIC(sharkbVYearMO)
coefficients(sharkbVYearMO)
fixef(ssharkbVYearMO)
ranef(sharkbVYearMO)

#MODEL 5

sharkbVYearMFO <- glmer(SMAb~(1|VESSEL) + YEAR + MONTH + FLEET + OBSERVER -1, data=WSMACPUEb,family=binomial)
summary(sharkbVYearMFO)
AIC(sharkbVYearMFO)
BIC(sharkbVYearMFO)
coefficients(sharkbVYearMFO)
fixef(sharkbVYearMFO)
ranef(sharkbVYearMFO)

#####BSH-GAMMA WEST ######################################

WBSHCPUE <- subset(westSharkCPUE, BSH>0)

#MODEL 1

sharkgV <- glmer(BSH~(1|VESSEL)-1, data=WBSHCPUE,family=Gamma(link=log))
summary(sharkgV)
AIC(sharkgV)
BIC(sharkgV)
coefficients(sharkgV)
exp(fixef(sharkgV))
ranef(sharkgV)

#MODEL 2

sharkgVYear <- glmer(BSH~(1|VESSEL)+YEAR-1, data=WBSHCPUE,family=Gamma(link=log))
summary(sharkgVYear)
AIC(sharkgVYear)
BIC(sharkgVYear)
coefficients(sharkgVYear)
exp(fixef(sharkgVYear))
ranef(sharkgVYear)

#MODEL 3

sharkgVYearM <- glmer(BSH~(1|VESSEL) + YEAR + MONTH -1, data=WBSHCPUE,family=Gamma(link=log))
summary(sharkgVYearM)
AIC(sharkgVYearM)
BIC(sharkgVYearM)
coefficients(sharkgVYearM)
exp(fixef(sharkgVYearM))
ranef(sharkgVYearM)

#MODEL 4

sharkgVYearMF <- glmer(BSH~(1|VESSEL) + YEAR + MONTH + FLEET -1, data=WBSHCPUE,family=Gamma(link=log))
summary(sharkgVYearMO)
AIC(sharkgVYearMO)
BIC(sharkgVYearMO)
coefficients(sharkgVYearMO)
exp(fixef(sharkgVYearMO))
ranef(sharkgVYearMO)

#MODEL 5

sharkgVYearMFO <- glmer(BSH~(1|VESSEL) + YEAR + MONTH + FLEET + OBSERVER -1, data=WBSHCPUE,family=Gamma(link=log))
summary(sharkgVYearMFO)
AIC(sharkgVYearMFO)
BIC(sharkgVYearMFO)
coefficients(sharkgVYearMFO)
exp(fixef(sharkgVYearMFO))
ranef(sharkgVYearMFO)

#####BSH-BINOMIAL WEST ################################

# MODEL BINARY OUTCOMES (catch or zero catch)

BSHCPUEb = westSharkCPUE

BSHCPUEb$BSHb=0
BSHCPUEb$BSHb[BSHCPUEb$BSH>0]=1

#MODEL 1

sharkbV <- glmer(BSHb~(1|VESSEL)-1, data=BSHCPUEb,family="binomial")
summary(sharkbV)
AIC(sharkbV)
BIC(sharkbV)
coefficients(sharkbV)
fixef(sharkbV)
ranef(sharkbV)

#MODEL 2

sharkbVYear <- glmer(BSHb~(1|VESSEL)+YEAR-1, data=BSHCPUEb,family="binomial")
summary(sharkbVYear)
AIC(sharkbVYear)
BIC(sharkbVYear)
coefficients(sharkbVYear)
fixef(sharkbVYear)
ranef(sharkbVYear)

#MODEL 3

sharkbVYearM <- glmer(BSHb~(1|VESSEL) + YEAR + MONTH -1, data=BSHCPUEb,family="binomial")
summary(sharkbVYearM)
AIC(sharkbVYearM)
BIC(sharkbVYearM)
coefficients(sharkbVYearM)
fixef(sharkbVYearM)
ranef(sharkbVYearM)

#MODEL 4

sharkbVYearMF <- glmer(BSHb~(1|VESSEL) + YEAR + MONTH + FLEET -1, data=BSHCPUEb,family="binomial")
summary(sharkbVYearMO)
AIC(sharkbVYearMO)
BIC(sharkbVYearMO)
coefficients(sharkbVYearMO)
fixef(sharkbVYearMO)
ranef(sharkbVYearMO)

#MODEL 5

sharkbVYearMFO <- glmer(BSHb~(1|VESSEL) + YEAR + MONTH + FLEET + OBSERVER -1, data=BSHCPUEb,family="binomial")
summary(sharkbVYearMFO)
AIC(sharkbVYearMFO)
BIC(sharkbVYearMFO)
coefficients(sharkbVYearMFO)
fixef(sharkbVYearMFO)
ranef(sharkbVYearMFO)



##### SW AREA ----
#####SMA-GAMMA SWEST ######################################

swestSharkCPUE <- droplevels(swestSharkCPUE)
SWSMACPUE <- subset(swestSharkCPUE, SMA>0)

#MODEL 1

sharkgV <- glmer(SMA~(1|VESSEL)-1,data=SWSMACPUE, family="Gamma"(link=log))
summary(sharkgV)
AIC(sharkgV)
BIC(sharkgV)
coefficients(sharkgV)
exp(fixef(sharkgV))
ranef(sharkgV)

#MODEL 2

sharkgVYear <- glmer(SMA~(1|VESSEL) + YEAR-1, data=SWSMACPUE,family="Gamma"(link=log))
summary(sharkgVYear)
AIC(sharkgVYear)
BIC(sharkgVYear)
coefficients(sharkgVYear)
exp(fixef(sharkgVYear))
ranef(sharkgVYear)

#MODEL 3

sharkgVYearM <- glmer(SMA~(1|VESSEL) + YEAR + MONTH -1, data=SWSMACPUE,family="Gamma"(link=log))
summary(sharkgVYearM)
AIC(sharkgVYearM)
BIC(sharkgVYearM)
coefficients(sharkgVYearM)
exp(fixef(sharkgVYearM))
ranef(sharkgVYearM)

#MODEL 4

sharkgVYearMF <- glmer(SMA~(1|VESSEL) + YEAR + MONTH + FLEET -1, data=SWSMACPUE,family="Gamma"(link=log))
summary(sharkgVYearMF)
AIC(sharkgVYearMF)
BIC(sharkgVYearMF)
coefficients(sharkgVYearMF)
exp(fixef(sharkgVYearMF))
ranef(sharkgVYearMF)

#MODEL 5

sharkgVYearMFO <- glmer(SMA~(1|VESSEL) + YEAR + MONTH + FLEET + OBSERVER-1, data=SWSMACPUE,family="Gamma"(link=log))
summary(sharkgVYearMFO)
AIC(sharkgVYearMFO)
BIC(sharkgVYearMFO)
coefficients(sharkgVYearMFO)
exp(fixef(sharkgVYearMFO))
ranef(sharkgVYearMFO)


#####SMA-BINOMIAL SWEST ################################

# MODEL BINARY OUTCOMES (catch or zero catch)

SWSMACPUEb = swestSharkCPUE

#make binary values of catch (0=no catch, 1 =catch)
SWSMACPUEb$SMAb=0
SWSMACPUEb$SMAb[SWSMACPUEb$SMA>0]=1

#MODEL 1

sharkbV <- glmer(SMAb~(1|VESSEL)-1, data=SWSMACPUEb,family=binomial)
summary(sharkbV)
AIC(sharkbV)
BIC(sharkbV)
coefficients(sharkbV)
fixef(sharkbV)
ranef(sharkbV)

#MODEL 2

sharkbVYear <- glmer(SMAb~(1|VESSEL) + YEAR -1, data=SWSMACPUEb,family=binomial)
summary(sharkbVYear)
AIC(sharkbVYear)
BIC(sharkbVYear)
coefficients(sharkbVYear)
fixef(sharkbVYear)
ranef(sharkbVYear)

#MODEL 3

sharkbVYearM <- glmer(SMAb~(1|VESSEL) + YEAR + MONTH -1,data=SWSMACPUEb,family=binomial)
summary(sharkbVYearM)
AIC(sharkbVYearM)
BIC(sharkbVYearM)
coefficients(sharkbVYearM)
fixef(sharkbVYearM)
ranef(sharkbVYearM)

#MODEL 4

sharkbVYearMF <- glmer(SMAb~(1|VESSEL) + YEAR + MONTH + FLEET -1, data=SWSMACPUEb,family=binomial)
summary(sharkbVYearMO)
AIC(sharkbVYearMO)
BIC(sharkbVYearMO)
coefficients(sharkbVYearMO)
fixef(ssharkbVYearMO)
ranef(sharkbVYearMO)

#MODEL 5

sharkbVYearMFO <- glmer(SMAb~(1|VESSEL) + YEAR + MONTH + FLEET + OBSERVER -1, data=SWSMACPUEb,family=binomial)
summary(sharkbVYearMFO)
AIC(sharkbVYearMFO)
BIC(sharkbVYearMFO)
coefficients(sharkbVYearMFO)
fixef(sharkbVYearMFO)
ranef(sharkbVYearMFO)


#####BSH-GAMMA SWEST ---- 

SWBSHCPUE <- subset(swestSharkCPUE, BSH>0)  

#MODEL 1

sharkgV <- glmer(BSH~(1|VESSEL)-1, data=SWBSHCPUE,family=Gamma(link=log))
summary(sharkgV)
AIC(sharkgV)
BIC(sharkgV)
coefficients(sharkgV)
exp(fixef(sharkgV))
ranef(sharkgV)

#MODEL 2

sharkgVYear <- glmer(BSH~(1|VESSEL)+YEAR-1, data=SWBSHCPUE,family=Gamma(link=log))
summary(sharkgVYear)
AIC(sharkgVYear)
BIC(sharkgVYear)
coefficients(sharkgVYear)
exp(fixef(sharkgVYear))
ranef(sharkgVYear)

#MODEL 3

sharkgVYearM <- glmer(BSH~(1|VESSEL) + YEAR + MONTH -1, data=SWBSHCPUE,family=Gamma(link=log))
summary(sharkgVYearM)
AIC(sharkgVYearM)
BIC(sharkgVYearM)
coefficients(sharkgVYearM)
exp(fixef(sharkgVYearM))
ranef(sharkgVYearM)

#MODEL 4

sharkgVYearMF <- glmer(BSH~(1|VESSEL) + YEAR + MONTH + FLEET -1, data=SWBSHCPUE,family=Gamma(link=log))
summary(sharkgVYearMO)
AIC(sharkgVYearMO)
BIC(sharkgVYearMO)
coefficients(sharkgVYearMO)
exp(fixef(sharkgVYearMO))
ranef(sharkgVYearMO)

#MODEL 5

sharkgVYearMFO <- glmer(BSH~(1|VESSEL) + YEAR + MONTH + FLEET + OBSERVER -1, data=SWBSHCPUE,family=Gamma(link=log))
summary(sharkgVYearMFO)
AIC(sharkgVYearMFO)
BIC(sharkgVYearMFO)
coefficients(sharkgVYearMFO)
exp(fixef(sharkgVYearMFO))
ranef(sharkgVYearMFO)


#####BSH-BINOMIAL SWEST ----

#make binary values of catch (0=no catch, 1 =catch)

SWBSHCPUEb = swestSharkCPUE

SWBSHCPUEb$BSHb=0
SWBSHCPUEb$BSHb[SWBSHCPUEb$BSH>0]=1

#MODEL 1

sharkbV <- glmer(BSHb~(1|VESSEL)-1, data=SWBSHCPUEb,family="binomial")
summary(sharkbV)
AIC(sharkbV)
BIC(sharkbV)
coefficients(sharkbV)
fixef(sharkbV)
ranef(sharkbV)

#MODEL 2

sharkbVYear <- glmer(BSHb~(1|VESSEL)+YEAR-1, data=SWBSHCPUEb,family="binomial")
summary(sharkbVYear)
AIC(sharkbVYear)
BIC(sharkbVYear)
coefficients(sharkbVYear)
fixef(sharkbVYear)
ranef(sharkbVYear)

#MODEL 3

sharkbVYearM <- glmer(BSHb~(1|VESSEL) + YEAR + MONTH -1, data=SWBSHCPUEb,family="binomial")
summary(sharkbVYearM)
AIC(sharkbVYearM)
BIC(sharkbVYearM)
coefficients(sharkbVYearM)
fixef(sharkbVYearM)
ranef(sharkbVYearM)

#MODEL 4

sharkbVYearMF <- glmer(BSHb~(1|VESSEL) + YEAR + MONTH + FLEET -1, data=SWBSHCPUEb,family="binomial")
summary(sharkbVYearMO)
AIC(sharkbVYearMO)
BIC(sharkbVYearMO)
coefficients(sharkbVYearMO)
fixef(sharkbVYearMO)
ranef(sharkbVYearMO)

#MODEL 5

sharkbVYearMFO <- glmer(BSHb~(1|VESSEL) + YEAR + MONTH + FLEET + OBSERVER -1, data=SWBSHCPUEb,family="binomial")
summary(sharkbVYearMFO)
AIC(sharkbVYearMFO)
BIC(sharkbVYearMFO)
coefficients(sharkbVYearMFO)
fixef(sharkbVYearMFO)
ranef(sharkbVYearMFO)



##### S AREA ----
#####SMA-GAMMA SOUTH ######################################

southSharkCPUE <- droplevels(southSharkCPUE)
SSMACPUE <- subset(southSharkCPUE, SMA>0)

#MODEL 1 

sharkgV <- glmer(SMA~(1|VESSEL)-1,data=SSMACPUE, family="Gamma"(link=log))
summary(sharkgV)
AIC(sharkgV)
BIC(sharkgV)
coefficients(sharkgV)
exp(fixef(sharkgV))
ranef(sharkgV)

#MODEL 2

sharkgVYear <- glmer(SMA~(1|VESSEL) + YEAR-1, data=SSMACPUE,family="Gamma"(link=log))
summary(sharkgVYear)
AIC(sharkgVYear)
BIC(sharkgVYear)
coefficients(sharkgVYear)
exp(fixef(sharkgVYear))
ranef(sharkgVYear)

#MODEL 3

sharkgVYearM <- glmer(SMA~(1|VESSEL) + YEAR + MONTH -1, data=SSMACPUE,family="Gamma"(link=log))
summary(sharkgVYearM)
AIC(sharkgVYearM)
BIC(sharkgVYearM)
coefficients(sharkgVYearM)
exp(fixef(sharkgVYearM))
ranef(sharkgVYearM)

#MODEL 4

sharkgVYearMF <- glmer(SMA~(1|VESSEL) + YEAR + MONTH + FLEET -1, data=SSMACPUE,family="Gamma"(link=log))
summary(sharkgVYearMF)
AIC(sharkgVYearMF)
BIC(sharkgVYearMF)
coefficients(sharkgVYearMF)
exp(fixef(sharkgVYearMF))
ranef(sharkgVYearMF)

#MODEL 5

sharkgVYearMFO <- glmer(SMA~(1|VESSEL) + YEAR + MONTH + FLEET + OBSERVER-1, data=SSMACPUE,family="Gamma"(link=log))
summary(sharkgVYearMFO)
AIC(sharkgVYearMFO)
BIC(sharkgVYearMFO)
coefficients(sharkgVYearMFO)
exp(fixef(sharkgVYearMFO))
ranef(sharkgVYearMFO)

#####SMA-BINOMIAL SOUTH################################

SSMACPUEb = southSharkCPUE

#make binary values of catch (0=no catch, 1 =catch)
SSMACPUEb$SMAb=0
SSMACPUEb$SMAb[SSMACPUEb$SMA>0]=1

#MODEL 1

sharkbV <- glmer(SMAb~(1|VESSEL)-1, data=SSMACPUEb,family=binomial)
summary(sharkbV)
AIC(sharkbV)
BIC(sharkbV)
coefficients(sharkbV)
fixef(sharkbV)
ranef(sharkbV)

#MODEL 2

sharkbVYear <- glmer(SMAb~(1|VESSEL) + YEAR -1, data=SSMACPUEb,family=binomial)
summary(sharkbVYear)
AIC(sharkbVYear)
BIC(sharkbVYear)
coefficients(sharkbVYear)
fixef(sharkbVYear)
ranef(sharkbVYear)

#MODEL 3

sharkbVYearM <- glmer(SMAb~(1|VESSEL) + YEAR + MONTH -1,data=SSMACPUEb,family=binomial)
summary(sharkbVYearM)
AIC(sharkbVYearM)
BIC(sharkbVYearM)
coefficients(sharkbVYearM)
fixef(sharkbVYearM)
ranef(sharkbVYearM)

#MODEL 4

sharkbVYearMF <- glmer(SMAb~(1|VESSEL) + YEAR + MONTH + FLEET -1, data=SSMACPUEb,family=binomial)
summary(sharkbVYearMO)
AIC(sharkbVYearMO)
BIC(sharkbVYearMO)
coefficients(sharkbVYearMO)
fixef(ssharkbVYearMO)
ranef(sharkbVYearMO)

#MODEL 5

sharkbVYearMFO <- glmer(SMAb~(1|VESSEL) + YEAR + MONTH + FLEET + OBSERVER -1, data=SSMACPUEb,family=binomial)
summary(sharkbVYearMFO)
AIC(sharkbVYearMFO)
BIC(sharkbVYearMFO)
coefficients(sharkbVYearMFO)
fixef(sharkbVYearMFO)
ranef(sharkbVYearMFO)

#####BSH-GAMMA SOUTH ---- 

SBSHCPUE <- subset(southSharkCPUE, BSH>0)  

#MODEL 1

sharkgV <- glmer(BSH~(1|VESSEL)-1, data=SBSHCPUE,family=Gamma(link=log))
summary(sharkgV)
AIC(sharkgV)
BIC(sharkgV)
coefficients(sharkgV)
exp(fixef(sharkgV))
ranef(sharkgV)

#MODEL 2

sharkgVYear <- glmer(BSH~(1|VESSEL)+YEAR-1, data=SBSHCPUE,family=Gamma(link=log))
summary(sharkgVYear)
AIC(sharkgVYear)
BIC(sharkgVYear)
coefficients(sharkgVYear)
exp(fixef(sharkgVYear))
ranef(sharkgVYear)

#MODEL 3

sharkgVYearM <- glmer(BSH~(1|VESSEL) + YEAR + MONTH -1, data=SBSHCPUE,family=Gamma(link=log))
summary(sharkgVYearM)
AIC(sharkgVYearM)
BIC(sharkgVYearM)
coefficients(sharkgVYearM)
exp(fixef(sharkgVYearM))
ranef(sharkgVYearM)

#MODEL 4

sharkgVYearMF <- glmer(BSH~(1|VESSEL) + YEAR + MONTH + FLEET -1, data=SBSHCPUE,family=Gamma(link=log))
summary(sharkgVYearMO)
AIC(sharkgVYearMO)
BIC(sharkgVYearMO)
coefficients(sharkgVYearMO)
exp(fixef(sharkgVYearMO))
ranef(sharkgVYearMO)

#MODEL 5

sharkgVYearMFO <- glmer(BSH~(1|VESSEL) + YEAR + MONTH + FLEET + OBSERVER -1, data=SBSHCPUE,family=Gamma(link=log))
summary(sharkgVYearMFO)
AIC(sharkgVYearMFO)
BIC(sharkgVYearMFO)
coefficients(sharkgVYearMFO)
exp(fixef(sharkgVYearMFO))
ranef(sharkgVYearMFO)


#####BSH-BINOMIAL SOUTH ----

#make binary values of catch (0=no catch, 1 =catch)

SBSHCPUEb = southSharkCPUE

SBSHCPUEb$BSHb=0
SBSHCPUEb$BSHb[SBSHCPUEb$BSH>0]=1

#MODEL 1

sharkbV <- glmer(BSHb~(1|VESSEL)-1, data=SBSHCPUEb,family="binomial")
summary(sharkbV)
AIC(sharkbV)
BIC(sharkbV)
coefficients(sharkbV)
fixef(sharkbV)
ranef(sharkbV)

#MODEL 2

sharkbVYear <- glmer(BSHb~(1|VESSEL)+YEAR-1, data=SBSHCPUEb,family="binomial")
summary(sharkbVYear)
AIC(sharkbVYear)
BIC(sharkbVYear)
coefficients(sharkbVYear)
fixef(sharkbVYear)
ranef(sharkbVYear)

#MODEL 3

sharkbVYearM <- glmer(BSHb~(1|VESSEL) + YEAR + MONTH -1, data=SBSHCPUEb,family="binomial")
summary(sharkbVYearM)
AIC(sharkbVYearM)
BIC(sharkbVYearM)
coefficients(sharkbVYearM)
fixef(sharkbVYearM)
ranef(sharkbVYearM)

#MODEL 4

sharkbVYearMF <- glmer(BSHb~(1|VESSEL) + YEAR + MONTH + FLEET -1, data=SBSHCPUEb,family="binomial")
summary(sharkbVYearMO)
AIC(sharkbVYearMO)
BIC(sharkbVYearMO)
coefficients(sharkbVYearMO)
fixef(sharkbVYearMO)
ranef(sharkbVYearMO)

#MODEL 5

sharkbVYearMFO <- glmer(BSHb~(1|VESSEL) + YEAR + MONTH + FLEET + OBSERVER -1, data=SBSHCPUEb,family="binomial")
summary(sharkbVYearMFO)
AIC(sharkbVYearMFO)
BIC(sharkbVYearMFO)
coefficients(sharkbVYearMFO)
fixef(sharkbVYearMFO)
ranef(sharkbVYearMFO)



##### E AREA ----
#####SMA-GAMMA EAST ######################################

eastSharkCPUE <- droplevels(eastSharkCPUE)
ESMACPUE <- subset(eastSharkCPUE, SMA>0)  

#MODEL 1

sharkgV <- glmer(SMA~(1|VESSEL)-1,data=ESMACPUE, family="Gamma"(link=log))
summary(sharkgV)
AIC(sharkgV)
BIC(sharkgV)
coefficients(sharkgV)
exp(fixef(sharkgV))
ranef(sharkgV)

#MODEL 2

sharkgVYear <- glmer(SMA~(1|VESSEL) + YEAR-1, data=ESMACPUE,family="Gamma"(link=log))
summary(sharkgVYear)
AIC(sharkgVYear)
BIC(sharkgVYear)
coefficients(sharkgVYear)
exp(fixef(sharkgVYear))
ranef(sharkgVYear)

#MODEL 3

sharkgVYearM <- glmer(SMA~(1|VESSEL) + YEAR + MONTH -1, data=ESMACPUE,family="Gamma"(link=log))
summary(sharkgVYearM)
AIC(sharkgVYearM)
BIC(sharkgVYearM)
coefficients(sharkgVYearM)
exp(fixef(sharkgVYearM))
ranef(sharkgVYearM)

#MODEL 4

sharkgVYearMF <- glmer(SMA~(1|VESSEL) + YEAR + MONTH + FLEET -1, data=ESMACPUE,family="Gamma"(link=log))
summary(sharkgVYearMF)
AIC(sharkgVYearMF)
BIC(sharkgVYearMF)
coefficients(sharkgVYearMF)
exp(fixef(sharkgVYearMF))
ranef(sharkgVYearMF)

#MODEL 5

sharkgVYearMFO <- glmer(SMA~(1|VESSEL) + YEAR + MONTH + FLEET + OBSERVER-1, data=ESMACPUE,family="Gamma"(link=log))
summary(sharkgVYearMFO)
AIC(sharkgVYearMFO)
BIC(sharkgVYearMFO)
coefficients(sharkgVYearMFO)
exp(fixef(sharkgVYearMFO))
ranef(sharkgVYearMFO)


#####SMA-BINOMIAL EAST ################################

ESMACPUEb = eastSharkCPUE

#make binary values of catch (0=no catch, 1 =catch)
ESMACPUEb$SMAb=0
ESMACPUEb$SMAb[ESMACPUEb$SMA>0]=1

#MODEL 1

sharkbV <- glmer(SMAb~(1|VESSEL)-1, data=ESMACPUEb,family=binomial)
summary(sharkbV)
AIC(sharkbV)
BIC(sharkbV)
coefficients(sharkbV)
fixef(sharkbV)
ranef(sharkbV)

#MODEL 2

sharkbVYear <- glmer(SMAb~(1|VESSEL) + YEAR -1, data=ESMACPUEb,family=binomial)
summary(sharkbVYear)
AIC(sharkbVYear)
BIC(sharkbVYear)
coefficients(sharkbVYear)
fixef(sharkbVYear)
ranef(sharkbVYear)

#MODEL 3

sharkbVYearM <- glmer(SMAb~(1|VESSEL) + YEAR + MONTH -1,data=ESMACPUEb,family=binomial)
summary(sharkbVYearM)
AIC(sharkbVYearM)
BIC(sharkbVYearM)
coefficients(sharkbVYearM)
fixef(sharkbVYearM)
ranef(sharkbVYearM)

#MODEL 4

sharkbVYearMF <- glmer(SMAb~(1|VESSEL) + YEAR + MONTH + FLEET -1, data=ESMACPUEb,family=binomial)
summary(sharkbVYearMO)
AIC(sharkbVYearMO)
BIC(sharkbVYearMO)
coefficients(sharkbVYearMO)
fixef(ssharkbVYearMO)
ranef(sharkbVYearMO)

#MODEL 5

sharkbVYearMFO <- glmer(SMAb~(1|VESSEL) + YEAR + MONTH + FLEET + OBSERVER -1, data=ESMACPUEb,family=binomial)
summary(sharkbVYearMFO)
AIC(sharkbVYearMFO)
BIC(sharkbVYearMFO)
coefficients(sharkbVYearMFO)
fixef(sharkbVYearMFO)
ranef(sharkbVYearMFO)


#####BSH-GAMMA EAST ---- 

#BSH#

EBSHCPUE <- subset(eastSharkCPUE, BSH>0)  

#MODEL 1

sharkgV <- glmer(BSH~(1|VESSEL)-1, data=EBSHCPUE,family=Gamma(link=log))
summary(sharkgV)
AIC(sharkgV)
BIC(sharkgV)
coefficients(sharkgV)
exp(fixef(sharkgV))
ranef(sharkgV)

#MODEL 2

sharkgVYear <- glmer(BSH~(1|VESSEL)+YEAR-1, data=EBSHCPUE,family=Gamma(link=log))
summary(sharkgVYear)
AIC(sharkgVYear)
BIC(sharkgVYear)
coefficients(sharkgVYear)
exp(fixef(sharkgVYear))
ranef(sharkgVYear)

#MODEL 3

sharkgVYearM <- glmer(BSH~(1|VESSEL) + YEAR + MONTH -1, data=EBSHCPUE,family=Gamma(link=log))
summary(sharkgVYearM)
AIC(sharkgVYearM)
BIC(sharkgVYearM)
coefficients(sharkgVYearM)
exp(fixef(sharkgVYearM))
ranef(sharkgVYearM)

#MODEL 4

sharkgVYearMF <- glmer(BSH~(1|VESSEL) + YEAR + MONTH + FLEET -1, data=EBSHCPUE,family=Gamma(link=log))
summary(sharkgVYearMO)
AIC(sharkgVYearMO)
BIC(sharkgVYearMO)
coefficients(sharkgVYearMO)
exp(fixef(sharkgVYearMO))
ranef(sharkgVYearMO)

#MODEL 5

sharkgVYearMFO <- glmer(BSH~(1|VESSEL) + YEAR + MONTH + FLEET + OBSERVER -1, data=EBSHCPUE,family=Gamma(link=log))
summary(sharkgVYearMFO)
AIC(sharkgVYearMFO)
BIC(sharkgVYearMFO)
coefficients(sharkgVYearMFO)
exp(fixef(sharkgVYearMFO))
ranef(sharkgVYearMFO)


#####BSH-BINOMIAL EAST ----

#make binary values of catch (0=no catch, 1 =catch)
EBSHCPUEb = eastSharkCPUE

EBSHCPUEb$BSHb=0
EBSHCPUEb$BSHb[EBSHCPUEb$BSH>0]=1

#MODEL 1

sharkbV <- glmer(BSHb~(1|VESSEL)-1, data=EBSHCPUEb,family="binomial")
summary(sharkbV)
AIC(sharkbV)
BIC(sharkbV)
coefficients(sharkbV)
fixef(sharkbV)
ranef(sharkbV)

#MODEL 2

sharkbVYear <- glmer(BSHb~(1|VESSEL)+YEAR-1, data=EBSHCPUEb,family="binomial")
summary(sharkbVYear)
AIC(sharkbVYear)
BIC(sharkbVYear)
coefficients(sharkbVYear)
fixef(sharkbVYear)
ranef(sharkbVYear)

#MODEL 3

sharkbVYearM <- glmer(BSHb~(1|VESSEL) + YEAR + MONTH -1, data=EBSHCPUEb,family="binomial")
summary(sharkbVYearM)
AIC(sharkbVYearM)
BIC(sharkbVYearM)
coefficients(sharkbVYearM)
fixef(sharkbVYearM)
ranef(sharkbVYearM)

#MODEL 4

sharkbVYearMF <- glmer(BSHb~(1|VESSEL) + YEAR + MONTH + FLEET -1, data=EBSHCPUEb,family="binomial")
summary(sharkbVYearMO)
AIC(sharkbVYearMO)
BIC(sharkbVYearMO)
coefficients(sharkbVYearMO)
fixef(sharkbVYearMO)
ranef(sharkbVYearMO)

#MODEL 5

sharkbVYearMFO <- glmer(BSHb~(1|VESSEL) + YEAR + MONTH + FLEET + OBSERVER -1, data=EBSHCPUEb,family="binomial")
summary(sharkbVYearMFO)
AIC(sharkbVYearMFO)
BIC(sharkbVYearMFO)
coefficients(sharkbVYearMFO)
fixef(sharkbVYearMFO)
ranef(sharkbVYearMFO)










#########FIXED EFFECTS




2. #########FISHING EFFORT DISTRIBUTION## ----
#########FISHING EFFORT LOCAL VESSELS ----

library(spatial)
library(MASS)
library(maps)
library(mapdata)
library(mapproj)

FishingEffort <- read.table("Raw_Data_Individual_Set_Data_GLMM_5.csv", header=TRUE, sep=",", na.strings="NA", strip.white=TRUE)

library(rgdal)
##SHAPE FILES USED FOR EEZ AND CONTINENTAL SHELF
shape <- readOGR(dsn = "C:/Users/gjordaan/Dropbox/Journal Papers/Shark bycatch", layer = "SA EEZ")
shape2 <- readOGR(dsn = "C:/Users/gjordaan/Dropbox/Journal Papers/Shark bycatch", layer = "0500m")

#ALL MONTHS

FELOCAL <- subset(FishingEffort, FLEET=="LOCAL")

LAT = FELOCAL$LAT
LONG = FELOCAL$LONG
EFFORT=FELOCAL$EFFORT
plot(LONG,LAT,xlim=c(8,42), ylim=c(-43,-24))
symbols(LONG, LAT, circles=EFFORT, xlim=c(14,38), ylim=c(-41,-24))
symbols(LONG, LAT, circles=EFFORT, inches=0.1, fg="black", bg="red", xlab="LONGITUDE", ylab="LATITUDE", xlim=c(8,42), ylim=c(-43,-27), cex.axis=0.80, cex.lab=0.90)
map.scale(x=32,y=-41, relwidth=0.15,metric=TRUE, ratio=FALSE)
map("worldHires", interior=FALSE, fill=TRUE, col="grey50", xlim=c(14,38), ylim=c(-41,-27), mar=c(1,1,1,1), add=TRUE)
plot(shape, col=rgb(0,0,0,alpha = 0.09), add=T)
plot(shape2, col=rgb(0,0,0,alpha = 0.05), add = T)

#WEST

FELOCAL <- subset(FishingEffort, FLEET=="LOCAL")
WEffortL <- subset(FELOCAL, REGION=="W")

LAT = WEffortL$LAT
LONG = WEffortL$LONG
EFFORT=WEffortL$EFFORT
plot(LONG,LAT,xlim=c(8,42), ylim=c(-43,-24))
symbols(LONG, LAT, circles=EFFORT, xlim=c(14,38), ylim=c(-41,-24))
symbols(LONG, LAT, circles=EFFORT, inches=0.1, fg="black", bg="grey", xlab="LONGITUDE", ylab="LATITUDE", xlim=c(8,42), ylim=c(-43,-27), cex.axis=0.80, cex.lab=0.90)
map.scale(x=32,y=-41, relwidth=0.15,metric=TRUE, ratio=FALSE)
map("worldHires", interior=FALSE, fill=TRUE, col="grey50", xlim=c(14,38), ylim=c(-41,-27), mar=c(1,1,1,1), add=TRUE)
plot(shape, col=rgb(0,0,0,alpha = 0.09), add=T)
plot(shape2, col=rgb(0,0,0,alpha = 0.05), add = T)


#SOUTHWEST

FELOCAL <- subset(FishingEffort, FLEET=="LOCAL")
SWEffortL <- subset(FELOCAL, REGION=="SW")

LAT = SWEffortL$LAT
LONG = SWEffortL$LONG
EFFORT=SWEffortL$EFFORT
plot(LONG,LAT,xlim=c(8,42), ylim=c(-43,-24))
symbols(LONG, LAT, circles=EFFORT, xlim=c(14,38), ylim=c(-41,-24))
symbols(LONG, LAT, circles=EFFORT, inches=0.1, fg="black", bg="grey", xlab="LONGITUDE", ylab="LATITUDE", xlim=c(8,42), ylim=c(-43,-27), cex.axis=0.80, cex.lab=0.90)
map.scale(x=32,y=-41, relwidth=0.15,metric=TRUE, ratio=FALSE)
map("worldHires", interior=FALSE, fill=TRUE, col="grey50", xlim=c(14,38), ylim=c(-41,-27), mar=c(1,1,1,1), add=TRUE)
plot(shape, col=rgb(0,0,0,alpha = 0.09), add=T)
plot(shape2, col=rgb(0,0,0,alpha = 0.05), add = T)


#SOUTH

FELOCAL <- subset(FishingEffort, FLEET=="LOCAL")
S_EffortL <- subset(FELOCAL, REGION=="S")

LAT = S_EffortL$LAT
LONG = S_EffortL$LONG
EFFORT=S_EffortL$EFFORT
plot(LONG,LAT,xlim=c(8,42), ylim=c(-43,-24))
symbols(LONG, LAT, circles=EFFORT, xlim=c(14,38), ylim=c(-41,-24))
symbols(LONG, LAT, circles=EFFORT, inches=0.1, fg="black", bg="grey", xlab="LONGITUDE", ylab="LATITUDE", xlim=c(8,42), ylim=c(-43,-27), cex.axis=0.80, cex.lab=0.90)
map.scale(x=32,y=-41, relwidth=0.15,metric=TRUE, ratio=FALSE)
map("worldHires", interior=FALSE, fill=TRUE, col="grey50", xlim=c(14,38), ylim=c(-41,-27), mar=c(1,1,1,1), add=TRUE)
plot(shape, col=rgb(0,0,0,alpha = 0.09), add=T)
plot(shape2, col=rgb(0,0,0,alpha = 0.05), add = T)


#EAST

FELOCAL <- subset(FishingEffort, FLEET=="LOCAL")
EEffortL <- subset(FELOCAL, REGION=="E")

LAT = EEffortL$LAT
LONG = EEffortL$LONG
EFFORT=EEffortL$EFFORT
plot(LONG,LAT,xlim=c(8,42), ylim=c(-43,-24))
symbols(LONG, LAT, circles=EFFORT, xlim=c(14,38), ylim=c(-41,-24))
symbols(LONG, LAT, circles=EFFORT, inches=0.1, fg="black", bg="grey", xlab="LONGITUDE", ylab="LATITUDE", xlim=c(8,42), ylim=c(-43,-27), cex.axis=0.80, cex.lab=0.90)
map.scale(x=32,y=-41, relwidth=0.15,metric=TRUE, ratio=FALSE)
map("worldHires", interior=FALSE, fill=TRUE, col="grey50", xlim=c(14,38), ylim=c(-41,-27), mar=c(1,1,1,1), add=TRUE)
plot(shape, col=rgb(0,0,0,alpha = 0.09), add=T)
plot(shape2, col=rgb(0,0,0,alpha = 0.05), add = T)


#########FISHING EFFORT FOREIGN VESSELS ----

#ALL MONTHS

FEFOREIGN <- subset(FishingEffort, FLEET=="FOREIGN")

LAT = FEFOREIGN$LAT
LONG = FEFOREIGN$LONG
EFFORT=FEFOREIGN$EFFORT
plot(LONG,LAT,xlim=c(8,42), ylim=c(-45,-27))
symbols(LONG, LAT, circles=EFFORT, xlim=c(8,42), ylim=c(-45,-27))
symbols(LONG, LAT, circles=EFFORT, inches=0.1, fg="black", bg="royalblue", xlab="LONGITUDE", ylab="LATITUDE", xlim=c(8,42), ylim=c(-45,-27), cex.axis=0.80, cex.lab=0.90)
map.scale(x=33,y=-42, relwidth=0.15,metric=TRUE, ratio=FALSE)
map("worldHires", interior=FALSE, fill=TRUE, col="grey50", xlim=c(9,41), ylim=c(-43,-27), mar=c(1,1,1,1), add=TRUE)
plot(shape, col=rgb(0,0,0,alpha = 0.09), add=T)
plot(shape2, col=rgb(0,0,0,alpha = 0.05), add = T)

#WEST

FEFOREIGN <- subset(FishingEffort, FLEET=="FOREIGN")
WEffortF <- subset(FEFOREIGN, REGION=="W")

LAT = WWEffortF$LAT
LONG = WEffortF$LONG
EFFORT=WEffortF$EFFORT
plot(LONG,LAT,xlim=c(8,42), ylim=c(-45,-27))
symbols(LONG, LAT, circles=EFFORT, xlim=c(8,42), ylim=c(-45,-27))
symbols(LONG, LAT, circles=EFFORT, inches=0.1, fg="black", bg="royalblue", xlab="LONGITUDE", ylab="LATITUDE", xlim=c(8,42), ylim=c(-45,-27), cex.axis=0.80, cex.lab=0.90)
map.scale(x=33,y=-42, relwidth=0.15,metric=TRUE, ratio=FALSE)
map("worldHires", interior=FALSE, fill=TRUE, col="grey50", xlim=c(9,41), ylim=c(-43,-27), mar=c(1,1,1,1), add=TRUE)
plot(shape, col=rgb(0,0,0,alpha = 0.09), add=T)
plot(shape2, col=rgb(0,0,0,alpha = 0.05), add = T)


#SOUTHWEST

FEFOREIGN <- subset(FishingEffort, FLEET=="FOREIGN")
SWEffortF <- subset(FEFOREIGN, REGION=="SW")

LAT = SWEffortF$LAT
LONG = SWEffortF$LONG
EFFORT=SWEffortF$EFFORT
plot(LONG,LAT,xlim=c(8,42), ylim=c(-45,-27))
symbols(LONG, LAT, circles=EFFORT, xlim=c(8,42), ylim=c(-45,-27))
symbols(LONG, LAT, circles=EFFORT, inches=0.1, fg="black", bg="royalblue", xlab="LONGITUDE", ylab="LATITUDE", xlim=c(8,42), ylim=c(-45,-27), cex.axis=0.80, cex.lab=0.90)
map.scale(x=33,y=-42, relwidth=0.15,metric=TRUE, ratio=FALSE)
map("worldHires", interior=FALSE, fill=TRUE, col="grey50", xlim=c(9,41), ylim=c(-43,-27), mar=c(1,1,1,1), add=TRUE)
plot(shape, col=rgb(0,0,0,alpha = 0.09), add=T)
plot(shape2, col=rgb(0,0,0,alpha = 0.05), add = T)

#SOUTH

FEFOREIGN <- subset(FishingEffort, FLEET=="FOREIGN")
S_EffortF <- subset(FEFOREIGN, REGION=="S")

LAT = S_EffortF$LAT
LONG = S_EffortF$LONG
EFFORT=S_EffortF$EFFORT
plot(LONG,LAT,xlim=c(8,42), ylim=c(-45,-27))
symbols(LONG, LAT, circles=EFFORT, xlim=c(8,42), ylim=c(-45,-27))
symbols(LONG, LAT, circles=EFFORT, inches=0.1, fg="black", bg="royalblue", xlab="LONGITUDE", ylab="LATITUDE", xlim=c(8,42), ylim=c(-45,-27), cex.axis=0.80, cex.lab=0.90)
map.scale(x=33,y=-42, relwidth=0.15,metric=TRUE, ratio=FALSE)
map("worldHires", interior=FALSE, fill=TRUE, col="grey50", xlim=c(9,41), ylim=c(-43,-27), mar=c(1,1,1,1), add=TRUE)
plot(shape, col=rgb(0,0,0,alpha = 0.09), add=T)
plot(shape2, col=rgb(0,0,0,alpha = 0.05), add = T)

#EAST

FEFOREIGN <- subset(FishingEffort, FLEET=="FOREIGN")
EEffortF <- subset(FEFOREIGN, REGION=="E")

LAT = EEffortL$LAT
LONG = EEffortL$LONG
EFFORT=EEffortL$EFFORT
plot(LONG,LAT,xlim=c(8,42), ylim=c(-45,-27))
symbols(LONG, LAT, circles=EFFORT, xlim=c(8,42), ylim=c(-45,-27))
symbols(LONG, LAT, circles=EFFORT, inches=0.1, fg="black", bg="royalblue", xlab="LONGITUDE", ylab="LATITUDE", xlim=c(8,42), ylim=c(-45,-27), cex.axis=0.80, cex.lab=0.90)
map.scale(x=33,y=-42, relwidth=0.15,metric=TRUE, ratio=FALSE)
map("worldHires", interior=FALSE, fill=TRUE, col="grey50", xlim=c(9,41), ylim=c(-43,-27), mar=c(1,1,1,1), add=TRUE)
plot(shape, col=rgb(0,0,0,alpha = 0.09), add=T)
plot(shape2, col=rgb(0,0,0,alpha = 0.05), add = T)

